Matrix Function - MFN

slepc-3.18.0 2022-10-01
Report Typos and Errors

## Matrix Function - MFN: Examples

Matrix Function (MFN) is the object provided by SLEPc for computing the action of a matrix function on a vector. Given a matrix A and a vector b, the call `MFNSolve(mfn,b,x)` computes x=f(A)b, where f is a function such as the exponential.

Beginner - Basic usage
| MFN | MFNSetFN | MFNSolveTranspose
MFNCreate | MFNSetFromOptions | MFNType
MFNDestroy | MFNSetOperator | MFNView
MFNGetFN | MFNSolve |
Intermediate - Setting options for algorithms and data structures
| MFNConvergedReason | MFNGetOperator | MFNMonitorSet
MFNConvergedReasonView | MFNGetTolerances | MFNSetDimensions
MFNGetConvergedReason | MFNGetType | MFNSetErrorIfNotConverged
MFNGetDimensions | MFNMonitorCancel | MFNSetTolerances
MFNGetErrorIfNotConverged | MFNMonitorDefault | MFNSetType
MFNGetIterationNumber | MFNMonitorDefaultDrawLG | MFNViewFromOptions
MFNGetMonitorContext | MFNMonitorDefaultDrawLGCreate |
Advanced - Setting more advanced options and customization
| MFNAppendOptionsPrefix | MFNMonitorRegisterAll | MFNSetBV
MFNGetBV | MFNRegister | MFNSetOptionsPrefix
MFNGetOptionsPrefix | MFNRegisterAll |
MFNMonitorRegister | MFNReset |
Developer - Interfaces intended primarily for library developers, not for typical applications programmers
| MFNAllocateSolution | MFNFinalizePackage | MFNMonitorSetFromOptions
MFNConvergedReasonViewFromOptions | MFNInitializePackage | MFNSetUp
No deprecated routines

Table of Contents